@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.workflows.executions_v1.types import executions
@@ -74,14 +74,14 @@ class ListExecutionsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[executions.ListExecutionsResponse]:
+    def pages(self) -> Iterator[executions.ListExecutionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[executions.Execution]:
+    def __iter__(self) -> Iterator[executions.Execution]:
         for page in self.pages:
             yield from page.executions
 
@@ -136,14 +136,14 @@ class ListExecutionsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[executions.ListExecutionsResponse]:
+    async def pages(self) -> AsyncIterator[executions.ListExecutionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[executions.Execution]:
+    def __aiter__(self) -> AsyncIterator[executions.Execution]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.executions:
